Devolve

Trait Devolve 

pub trait Devolve<T> {
    type Devolved: Evolve<T, Evolved = Self>;

    // Required method
    fn into_devolved(self) -> Self::Devolved;
}
A data structure which represents the complete, or latest known form of another devolved data structure, and which may be converted into this “devolved” form.

Additionally, serde-devo provides a procedural macro called serde_devo_derive to automatically implement Devolvable for structs and enums in your program.

In rare cases it may be necessary to implement Devolvable manually for some type in your program.

Required Associated Types

type Devolved: Evolve<T, Evolved = Self>

Required Methods

fn into_devolved(self) -> Self::Devolved

Implementors